package com.game.business.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppGameClassify;

/**
 * 游戏分类Mapper接口
 *
 * @author dos
 * @date 2024-06-14
 */
public interface AppGameClassifyMapper extends BaseMapper<AppGameClassify> {
    /**
     * 查询游戏分类
     *
     * @param id 游戏分类主键
     * @return 游戏分类
     */
    public AppGameClassify selectAppGameClassifyById(Long id);

    /**
     * 查询游戏分类列表
     *
     * @param appGameClassify 游戏分类
     * @return 游戏分类集合
     */
    public List<AppGameClassify> selectAppGameClassifyList(AppGameClassify appGameClassify);

    /**
     * 新增游戏分类
     *
     * @param appGameClassify 游戏分类
     * @return 结果
     */
    public int insertAppGameClassify(AppGameClassify appGameClassify);

    /**
     * 修改游戏分类
     *
     * @param appGameClassify 游戏分类
     * @return 结果
     */
    public int updateAppGameClassify(AppGameClassify appGameClassify);

    /**
     * 删除游戏分类
     *
     * @param id 游戏分类主键
     * @return 结果
     */
    public int deleteAppGameClassifyById(Long id);

    /**
     * 批量删除游戏分类
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppGameClassifyByIds(Long[] ids);
}